==> jc-smec-domain-0.3.18-sources.jar: com/xforceplus/jcsmec/entity/FlowInstanceLog.java <==
package com.xforceplus.jcsmec.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2022-10-10
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class FlowInstanceLog implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 流程实例ID
   */
  @TableField("instanceId")
  private String instanceId;

  /**
   * 流程编码
   */
  @TableField("flowCode")
  private String flowCode;

  /**
   * 失败消息
   */
  @TableField("errorMsg")
  private String errorMsg;

  /**
   * 失败错误堆栈
   */
  @TableField("exceptionTrace")
  private String exceptionTrace;

  /**
   * 失败节点id
   */
  @TableField("errorNodeId")
  private String errorNodeId;

  /**
   * 是否回滚
   */
  private Boolean rollback;

  /**
   * 流程快照
   */
  private String snapshot;

  /**
   * 文件或者直接存
   */
  @TableField("snapshotFormat")
  private String snapshotFormat;

  /**
   * 事务回滚节点
   */
  @TableField("rollbackNodeId")
  private String rollbackNodeId;

  /**
   * 流程名称
   */
  @TableField("flowName")
  private String flowName;

  /**
   * 执行状态
   */
  private String status;

  /**
   * 初始流程快照
   */
  @TableField("startSnapshot")
  private String startSnapshot;

  /**
   * 快照格式
   */
  @TableField("startSnapshotFormat")
  private String startSnapshotFormat;

  /**
   * 用户上下文快照
   */
  @TableField("userContext")
  private String userContext;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("instanceId", instanceId);
      map.put("flowCode", flowCode);
      map.put("errorMsg", errorMsg);
      map.put("exceptionTrace", exceptionTrace);
      map.put("errorNodeId", errorNodeId);
      map.put("rollback", rollback);
      map.put("snapshot", snapshot);
      map.put("snapshotFormat", snapshotFormat);
      map.put("rollbackNodeId", rollbackNodeId);
      map.put("flowName", flowName);
      map.put("status", status);
      map.put("startSnapshot", startSnapshot);
      map.put("startSnapshotFormat", startSnapshotFormat);
      map.put("userContext", userContext);
      return map;
  }

  public static FlowInstanceLog fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    FlowInstanceLog entity = new FlowInstanceLog();
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("instanceId")) {
      Object obj = map.get("instanceId");
      if(obj != null) {
        if(obj instanceof String){
          entity.setInstanceId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("flowCode")) {
      Object obj = map.get("flowCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setFlowCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("errorMsg")) {
      Object obj = map.get("errorMsg");
      if(obj != null) {
        if(obj instanceof String){
          entity.setErrorMsg((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("exceptionTrace")) {
      Object obj = map.get("exceptionTrace");
      if(obj != null) {
        if(obj instanceof String){
          entity.setExceptionTrace((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("errorNodeId")) {
      Object obj = map.get("errorNodeId");
      if(obj != null) {
        if(obj instanceof String){
          entity.setErrorNodeId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("rollback")) {
      Object obj = map.get("rollback");
      if(obj != null) {
        if(obj instanceof Boolean) {
          entity.setRollback((Boolean)obj);
        } else if(obj instanceof String) {
          entity.setRollback(Boolean.valueOf((String)obj));
        }
      } else{
      }
    }
    if(map.containsKey("snapshot")) {
      Object obj = map.get("snapshot");
      if(obj != null) {
        if(obj instanceof String){
          entity.setSnapshot((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("snapshotFormat")) {
      Object obj = map.get("snapshotFormat");
      if(obj != null) {
        if(obj instanceof String){
          entity.setSnapshotFormat((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("rollbackNodeId")) {
      Object obj = map.get("rollbackNodeId");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRollbackNodeId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("flowName")) {
      Object obj = map.get("flowName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setFlowName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("startSnapshot")) {
      Object obj = map.get("startSnapshot");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStartSnapshot((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("startSnapshotFormat")) {
      Object obj = map.get("startSnapshotFormat");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStartSnapshotFormat((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("userContext")) {
      Object obj = map.get("userContext");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUserContext((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}

==> jc-smec-domain-0.4.228-sources.jar: com/xforceplus/jcsmec/entity/FlowInstanceLog.java <==
package com.xforceplus.jcsmec.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import com.xforceplus.ultraman.bocp.gen.obj.MetadataConvertable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2023-12-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class FlowInstanceLog implements MetadataConvertable, Serializable {

  private static final long serialVersionUID=1L;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 流程实例ID
   */
  @TableField("instanceId")
  private String instanceId;

  /**
   * 流程编码
   */
  @TableField("flowCode")
  private String flowCode;

  /**
   * 失败消息
   */
  @TableField("errorMsg")
  private String errorMsg;

  /**
   * 失败错误堆栈
   */
  @TableField("exceptionTrace")
  private String exceptionTrace;

  /**
   * 失败节点id
   */
  @TableField("errorNodeId")
  private String errorNodeId;

  /**
   * 是否回滚
   */
  private Boolean rollback;

  /**
   * 流程快照
   */
  private String snapshot;

  /**
   * 文件或者直接存
   */
  @TableField("snapshotFormat")
  private String snapshotFormat;

  /**
   * 事务回滚节点
   */
  @TableField("rollbackNodeId")
  private String rollbackNodeId;

  /**
   * 流程名称
   */
  @TableField("flowName")
  private String flowName;

  /**
   * 执行状态
   */
  private String status;

  /**
   * 初始流程快照
   */
  @TableField("startSnapshot")
  private String startSnapshot;

  /**
   * 快照格式
   */
  @TableField("startSnapshotFormat")
  private String startSnapshotFormat;

  /**
   * 用户上下文快照
   */
  @TableField("userContext")
  private String userContext;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("instanceId", instanceId);
      map.put("flowCode", flowCode);
      map.put("errorMsg", errorMsg);
      map.put("exceptionTrace", exceptionTrace);
      map.put("errorNodeId", errorNodeId);
      map.put("rollback", rollback);
      map.put("snapshot", snapshot);
      map.put("snapshotFormat", snapshotFormat);
      map.put("rollbackNodeId", rollbackNodeId);
      map.put("flowName", flowName);
      map.put("status", status);
      map.put("startSnapshot", startSnapshot);
      map.put("startSnapshotFormat", startSnapshotFormat);
      map.put("userContext", userContext);

      return map;
  }

  public static FlowInstanceLog fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    FlowInstanceLog entity = new FlowInstanceLog();
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("instanceId")) {
      Object obj = map.get("instanceId");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setInstanceId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("flowCode")) {
      Object obj = map.get("flowCode");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setFlowCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("errorMsg")) {
      Object obj = map.get("errorMsg");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setErrorMsg((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("exceptionTrace")) {
      Object obj = map.get("exceptionTrace");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setExceptionTrace((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("errorNodeId")) {
      Object obj = map.get("errorNodeId");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setErrorNodeId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("rollback")) {
      Object obj = map.get("rollback");
      if(obj != null) {
        if(obj instanceof Boolean) {
          entity.setRollback((Boolean)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setRollback(Boolean.valueOf((String)obj));
        }
      } else{
      }
    }
    if(map.containsKey("snapshot")) {
      Object obj = map.get("snapshot");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setSnapshot((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("snapshotFormat")) {
      Object obj = map.get("snapshotFormat");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setSnapshotFormat((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("rollbackNodeId")) {
      Object obj = map.get("rollbackNodeId");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setRollbackNodeId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("flowName")) {
      Object obj = map.get("flowName");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setFlowName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("startSnapshot")) {
      Object obj = map.get("startSnapshot");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setStartSnapshot((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("startSnapshotFormat")) {
      Object obj = map.get("startSnapshotFormat");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setStartSnapshotFormat((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("userContext")) {
      Object obj = map.get("userContext");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setUserContext((String)obj);
        }
      } else{
      }
    }

    return entity;
  }


  protected void setByOQSMap(Map map) {
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setTenantId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setTenantId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String) {
          this.setTenantCode((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setCreateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setUpdateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setCreateUserName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setUpdateUserName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String) {
          this.setDeleteFlag((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("instanceId")) {
      Object obj = map.get("instanceId");
      if(obj != null) {
        if(obj instanceof String) {
          this.setInstanceId((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("flowCode")) {
      Object obj = map.get("flowCode");
      if(obj != null) {
        if(obj instanceof String) {
          this.setFlowCode((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("errorMsg")) {
      Object obj = map.get("errorMsg");
      if(obj != null) {
        if(obj instanceof String) {
          this.setErrorMsg((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("exceptionTrace")) {
      Object obj = map.get("exceptionTrace");
      if(obj != null) {
        if(obj instanceof String) {
          this.setExceptionTrace((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("errorNodeId")) {
      Object obj = map.get("errorNodeId");
      if(obj != null) {
        if(obj instanceof String) {
          this.setErrorNodeId((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("rollback")) {
      Object obj = map.get("rollback");
      if(obj != null) {
        if(obj instanceof Boolean) {
          this.setRollback((Boolean)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setRollback(Boolean.valueOf((String)obj));
        }
      } else {
      }
    }
    if(map.containsKey("snapshot")) {
      Object obj = map.get("snapshot");
      if(obj != null) {
        if(obj instanceof String) {
          this.setSnapshot((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("snapshotFormat")) {
      Object obj = map.get("snapshotFormat");
      if(obj != null) {
        if(obj instanceof String) {
          this.setSnapshotFormat((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("rollbackNodeId")) {
      Object obj = map.get("rollbackNodeId");
      if(obj != null) {
        if(obj instanceof String) {
          this.setRollbackNodeId((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("flowName")) {
      Object obj = map.get("flowName");
      if(obj != null) {
        if(obj instanceof String) {
          this.setFlowName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String) {
          this.setStatus((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("startSnapshot")) {
      Object obj = map.get("startSnapshot");
      if(obj != null) {
        if(obj instanceof String) {
          this.setStartSnapshot((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("startSnapshotFormat")) {
      Object obj = map.get("startSnapshotFormat");
      if(obj != null) {
        if(obj instanceof String) {
          this.setStartSnapshotFormat((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("userContext")) {
      Object obj = map.get("userContext");
      if(obj != null) {
        if(obj instanceof String) {
          this.setUserContext((String)obj);
        }
      } else {
      }
    }
  }
}
